@@ -1,7 +1,7 @@
 #' return package dependencies from NAMESPACE file
 #'
 #' @param path path to NAMESPACE file
-#' @param document Run function document of devtools package
+#' @param document Run function roxygenise of roxygen2 package
 #'
 #' @return a vector
 #' @export
@@ -15,11 +15,13 @@
 #'  recursive = TRUE)
 #' dummypackage <- file.path(tmpdir, "dummypackage")
 #' # browseURL(dummypackage)
-#' att_from_namespace(path = file.path(dummypackage,"NAMESPACE"))
+#' att_from_namespace(path = file.path(dummypackage, "NAMESPACE"))
 
 att_from_namespace <- function(path = "NAMESPACE", document = TRUE) {
   if (isTRUE(document)) {
-    devtools::document(dirname(path))
+    message("Updating ", basename(dirname(normalizePath(path))), " documentation")
+    # devtools::document(dirname(path))
+    roxygen2::roxygenise(dirname(normalizePath(path)), roclets = NULL)
   }
   readLines(path)
   base <- try(read.table(path)[["V1"]], silent = TRUE)
