@@ -15,10 +15,11 @@
 #' att_from_rmd(path = file.path(dummypackage,"vignettes/demo.Rmd"))
 #'
 #' @export
-att_from_rmd <- function(path, temp_dir = tempdir(), warn = -1, encoding = getOption("encoding")) {
+att_from_rmd <- function(path, temp_dir = tempdir(), warn = -1,
+                         encoding = getOption("encoding")) {
   if (missing(path)) {stop("argument 'path' is missing, with no default")}
 
-  r_file <- normalizePath(file.path(temp_dir, basename(gsub(".Rmd$", ".R", path))), mustWork = FALSE, winslash = "\\")
+  r_file <- normalizePath(file.path(temp_dir, basename(gsub("[.]([[:alnum:]])*$", ".R", path))), mustWork = FALSE, winslash = "\\")
   path <- normalizePath(path, winslash = "\\")
 
   # Need an external script to run on windows because of \\ path
@@ -45,6 +46,7 @@ att_from_rmd <- function(path, temp_dir = tempdir(), warn = -1, encoding = getOp
 #' Get all packages called in vignettes folder
 #'
 #' @param path path to directory with Rmds or vector of Rmd files
+#' @param pattern pattern to detect Rmd files
 #' @param recursive logical. Should the listing recurse into directories?
 #' @inheritParams att_from_rmd
 #'
@@ -58,17 +60,17 @@ att_from_rmd <- function(path, temp_dir = tempdir(), warn = -1, encoding = getOp
 #' att_from_rmds(path = file.path(dummypackage,"vignettes"))
 
 #' @export
-att_from_rmds <- function(path = "vignettes", recursive = TRUE, warn = -1) {
+att_from_rmds <- function(path = "vignettes", pattern = "*.[.](Rmd|rmd)$", recursive = TRUE, warn = -1) {
 
   if (isTRUE(all(dir.exists(path)))) {
-    all_f <- list.files(path, full.names = TRUE, pattern = "*.Rmd$|*.rmd$", recursive = recursive)
+    all_f <- list.files(path, full.names = TRUE, pattern = pattern, recursive = recursive)
   } else if (isTRUE(all(file.exists(path)))) {
-    all_f <- normalizePath(path[grepl("*.Rmd$|*.rmd$", path)])
+    all_f <- normalizePath(path[grepl(pattern, path)])
   } else {
     stop("Some file/directory do not exists")
   }
 
-  res <- lapply(all_f, function(x) att_from_rmd(x, , warn = warn)) %>%
+  res <- lapply(all_f, function(x) att_from_rmd(x, warn = warn)) %>%
     unlist() %>%
     unique() %>%
     na.omit()
